While the syntax may suggest that the function
extracts a fitted fgpm model, this not true. The
fgpm model is refitted using the call that was used
when this model was assessed. The refitted fgpm model
keeps the same structural parameters as the one assessed
(active variables, kernel, ...), but since the optimization
uses random initial values, the optimized hyper-parameters may
differ from those of the corresponding fgpm in the
Xfgpm object x. As a result, the model can be
different and show a different LOO performance.